@@ -1,10 +1,10 @@
 package Net::DNS::RR;
 
 #
-# $Id: RR.pm 1186 2014-04-03 10:18:38Z willem $
+# $Id: RR.pm 1210 2014-05-29 10:26:18Z willem $
 #
 use vars qw($VERSION);
-$VERSION = (qw$LastChangedRevision: 1186 $)[1];
+$VERSION = (qw$LastChangedRevision: 1210 $)[1];
 
 
 =head1 NAME
@@ -32,7 +32,12 @@ See also the manual pages for each specific RR type.
 =cut
 
 
-use constant COMPATIBLE => 1;		## enable architecture transition code
+use constant COMPATIBLE => eval {	## enable architecture transition code
+	return 0 if $] < 5.006;
+	require Net::DNS::RR::DS;	## Net::DNS::SEC 0.17 compatible
+	( $Net::DNS::RR::DS::VERSION || 0 ) < 1133;
+} || 0;
+
 
 use strict;
 use integer;
@@ -87,7 +92,7 @@ The trailing dot (.) is optional.
 
 =cut
 
-my $PARSE_REGEX = q/("[^"]*"|'[^']*')|;[^\n]*|\s|\)$/;
+my $PARSE_REGEX = q/("[^"]*"|'[^']*')|;[^\n]*|[\s()]/;
 
 sub _new_string {
 	my $base;
@@ -99,10 +104,11 @@ sub _new_string {
 	s/\\\\/\\092/g;						# disguise escaped escape
 	s/\\"/\\034/g;						# disguise escaped double quote
 	s/\\'/\\039/g;						# disguise escaped single quote
+	s/\\\(/\\040/g;						# disguise escaped bracket
+	s/\\\)/\\041/g;						# disguise escaped bracket
 	s/\\;/\\059/g;						# disguise escaped semicolon
 	s/\n(\S)/$1/g if COMPATIBLE;				# gloss over syntax errors in Net::DNS::SEC test data
-	my @parse = grep defined && length, split /$PARSE_REGEX/o;
-	my ( $name, @token ) = grep !/^[()]$/, @parse;		# discard brackets
+	my ( $name, @token ) = grep defined && length, split /$PARSE_REGEX/o;
 
 	my ( $t1, $t2, $t3 ) = @token;
 	croak 'unable to parse RR string' unless defined $t1;
@@ -126,8 +132,8 @@ sub _new_string {
 
 	my $self = $base->_subclass( $type, $populated );	# create RR object
 	$self->name($name);
-	$self->ttl($ttl) if defined $ttl;			# undefined TTL meaningful in zone file
-	$self->class($class) if defined $class;
+	$self->class($class) if defined $class;			# specify CLASS
+	$self->ttl($ttl)     if defined $ttl;			# specify TTL
 
 	return $self unless $populated;				# empty RR
 
@@ -422,12 +428,12 @@ my %unit = ( W => 604800, D => 86400, H => 3600, M => 60, S => 1 );
 %unit = ( %unit, map { /\D/ ? lc($_) : $_ } %unit );
 
 sub ttl {
-	my $self = shift;
+	my ( $self, $time ) = @_;
 
-	return $self->{ttl} || 0 unless scalar @_;		# avoid defining rr->{ttl}
+	return $self->{ttl} || 0 unless defined $time;		# avoid defining rr->{ttl}
 
 	my $ttl = 0;
-	my %time = reverse split /(\D)\D*/, shift() . 'S';
+	my %time = reverse split /(\D)\D*/, $time . 'S';
 	while ( my ( $u, $t ) = each %time ) {
 		$ttl += $t * ( $unit{$u} || croak qq(bad time: $t$u) );
 	}
@@ -665,10 +671,8 @@ sub defaults { }			## set attribute default values
 
 sub dump {				## print internal data structure
 	require Data::Dumper;
-	local $Data::Dumper::Sortkeys;
-	$Data::Dumper::Sortkeys = 1;
-	return Data::Dumper::Dumper(shift) if defined wantarray;
-	print Data::Dumper::Dumper(shift);
+	local $Data::Dumper::Sortkeys = 1;
+	print Data::Dumper::Dumper(@_);
 }
 
 
