@@ -1,12 +1,14 @@
 package Net::DNS::RR::RP;
 
 #
-# $Id: RP.pm 1037 2012-10-24 21:50:15Z willem $
+# $Id: RP.pm 1189 2014-04-03 20:41:48Z willem $
 #
 use vars qw($VERSION);
-$VERSION = (qw$LastChangedRevision: 1037 $)[1];
+$VERSION = (qw$LastChangedRevision: 1189 $)[1];
 
-use base Net::DNS::RR;
+
+use strict;
+use base qw(Net::DNS::RR);
 
 =head1 NAME
 
@@ -15,7 +17,6 @@ Net::DNS::RR::RP - DNS RP resource record
 =cut
 
 
-use strict;
 use integer;
 
 use Net::DNS::DomainName;
@@ -26,8 +27,8 @@ sub decode_rdata {			## decode rdata from wire-format octet string
 	my $self = shift;
 	my ( $data, $offset, @opaque ) = @_;
 
-	( $self->{mbox}, $offset ) = decode Net::DNS::Mailbox2535($data,$offset,@opaque );
-	$self->{txtdname} = decode Net::DNS::DomainName2535($data,$offset,@opaque );
+	( $self->{mbox}, $offset ) = decode Net::DNS::Mailbox2535( $data, $offset, @opaque );
+	$self->{txtdname} = decode Net::DNS::DomainName2535( $data, $offset, @opaque );
 }
 
 
@@ -44,8 +45,9 @@ sub encode_rdata {			## encode rdata as wire-format octet string
 sub format_rdata {			## format rdata portion of RR string.
 	my $self = shift;
 
-	return '' unless $self->{txtdname};
-	join ' ', map $self->{$_}->string, qw(mbox txtdname);
+	my $mbx = $self->{mbox} || return '';
+	my $txt = $self->{txtdname} || return '';
+	join ' ', $mbx->string, $txt->string;
 }
 
 
@@ -59,14 +61,15 @@ sub parse_rdata {			## populate RR from rdata in argument list
 sub mbox {
 	my $self = shift;
 
-	$self->{mbox} = new Net::DNS::Mailbox2535(shift) if @_;
+	$self->{mbox} = new Net::DNS::Mailbox2535(shift) if scalar @_;
 	$self->{mbox}->address if defined wantarray;
 }
 
+
 sub txtdname {
 	my $self = shift;
 
-	$self->{txtdname} = new Net::DNS::DomainName2535(shift) if @_;
+	$self->{txtdname} = new Net::DNS::DomainName2535(shift) if scalar @_;
 	$self->{txtdname}->name if defined wantarray;
 }
 
@@ -96,6 +99,7 @@ other unpredictable behaviour.
 =head2 mbox
 
     $mbox = $rr->mbox;
+    $rr->mbox( $mbox );
 
 A domain name which specifies the mailbox for the person
 responsible for this domain.  Its format in master files uses the
@@ -106,6 +110,7 @@ the RNAME mailbox field in the SOA RR.  The root domain name (just
 =head2 txtdname
 
     $txtdname = $rr->txtdname;
+    $rr->txtdname( $txtdname );
 
 A domain name identifying TXT RRs.  A subsequent
 query can be performed to retrieve the associated TXT records.
@@ -119,13 +124,13 @@ TXT RR exists.
 
 Copyright (c)1997-2002 Michael Fuhr. 
 
-Package template (c)2009,2012 O.M.Kolkman and R.W.Franks.
-
 All rights reserved.
 
 This program is free software; you may redistribute it and/or
 modify it under the same terms as Perl itself.
 
+Package template (c)2009,2012 O.M.Kolkman and R.W.Franks.
+
 
 =head1 SEE ALSO
 
